Writing Scripts
===============

yt, at its heart, is a scripting interface.

Running Scripts from the Command Line
-------------------------------------

Running Scripts inside Reason
-----------------------------


